@@ -218,7 +218,7 @@ class HotEmissionsModel:
             ],
         ).transpose("component", "powertrain", "euro_class", "variable")
 
-        distance = self.cycle.sum() / 3600
+        distance = (self.cycle / 3600).sum(axis=0)
 
         # Emissions for each second of the driving cycle equal:
         # a * energy consumption
@@ -571,28 +571,40 @@ class HotEmissionsModel:
 
             urban = (
                 final_emissions.sel(second=range(urban_start, urban_stop)).sum(axis=-1)
-                / distance
+                / distance[:, None, None, None]
             )
             suburban = (
                 final_emissions.sel(second=range(suburban_start, suburban_stop)).sum(
                     axis=-1
                 )
-                / distance
+                / distance[:, None, None, None]
             )
             rural = (
                 final_emissions.sel(second=range(rural_start, rural_stop)).sum(axis=-1)
-                / distance
+                / distance[:, None, None, None]
             )
 
         else:
-            urban = final_emissions.where(self.cycle <= 50).sum(axis=-1) / distance
-            suburban = (
-                final_emissions.where((self.cycle > 50) & (self.cycle <= 80)).sum(
+
+            urban = (
+                final_emissions.where(self.cycle.T[:, None, None, None, :] <= 50).sum(
                     axis=-1
                 )
-                / distance
+                / distance[:, None, None, None]
+            )
+            suburban = (
+                final_emissions.where(
+                    (self.cycle.T[:, None, None, None, :] > 50)
+                    & (self.cycle.T[:, None, None, None, :] <= 80)
+                ).sum(axis=-1)
+                / distance[:, None, None, None]
+            )
+            rural = (
+                final_emissions.where(self.cycle.T[:, None, None, None, :] > 80).sum(
+                    axis=-1
+                )
+                / distance[:, None, None, None]
             )
-            rural = final_emissions.where(self.cycle > 80).sum(axis=-1) / distance
 
         urban *= np.isfinite(urban)
         suburban *= np.isfinite(suburban)
